pub enum XmlNodeType {
Element,
Attribute,
Text,
Cdata,
None,
}Expand description
The kind of XML DOM node a schema describes.
Used by the OpenAPI 3.2 Xml::node_type field.
See https://spec.openapis.org/oas/v3.2.0.html#xml-node-types.
Variants
Element
The schema represents an element and describes its contents.
Attribute
The schema represents an attribute and describes its value.
Text
The schema represents a text node (parsed character data).
Cdata
The schema represents a CDATA section.
None
The schema does not correspond to any node; nodes for its subschemas are placed directly under the parent schema’s node.