Struct salvo_oapi::extract::QueryParam
source · pub struct QueryParam<T, const REQUIRED: bool>(/* private fields */);Expand description
Represents the parameters passed by the URI path.
Implementations
sourceimpl<T> QueryParam<T, true>
impl<T> QueryParam<T, true>
sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes self and returns the value of the parameter.
sourceimpl<T> QueryParam<T, false>
impl<T> QueryParam<T, false>
sourcepub fn into_inner(self) -> Option<T>
pub fn into_inner(self) -> Option<T>
Consumes self and returns the value of the parameter.