pub enum ParameterIn {
Query,
QueryString,
Path,
Header,
Cookie,
}Expand description
Possible values for the OpenAPI parameter in field, indicating where the parameter
is located in the request.
Variants
Query
Declares that parameter is used as query parameter.
Must not appear in the same operation as a ParameterIn::QueryString parameter.
QueryString
Declares that the parameter is the entire URL query string, treated as a single value. Added in OpenAPI 3.2.
Such a parameter must describe its value with Parameter::content rather than
Parameter::schema, must not appear more than once, and must not be combined with any
ParameterIn::Query parameter in the same operation.
See https://spec.openapis.org/oas/v3.2.0.html#parameter-locations.
Path
Declares that parameter is used as path parameter.
Header
Declares that parameter is used as header value.
Cookie
Declares that parameter is used as cookie value.