Module schema

Module schema 

Implements OpenAPI Schema Object types which can be used to define field properties, enum values, array or object types.

Structs

AllOf
AllOf Composite Object component holds multiple components together where API endpoint will return a combination of all of them.
AnyOf
AnyOf Composite Object component holds multiple components together where API endpoint will return a combination of all of them.
Array
Array represents Vec or slice type of items.
Discriminator
OpenAPI Discriminator object which can be optionally used together with OneOf composite object.
Object
Implements subset of OpenAPI Schema Object which allows adding other Schemas as properties to this Schema.
OneOf
OneOf Composite Object component holds multiple components together where API endpoint could return any of them.
Ref
Implements OpenAPI Reference Object that can be used to reference reusable components such as Schemas or Responses.
Schemas
Schemas collection for OpenApi.

Enums

AdditionalProperties
AdditionalProperties is used to define values of map fields of the Schema.
ArrayItems
Represents Array items in JSON Schema Array.
BasicType
Represents data type fragment of Schema.
KnownFormat
Known schema format modifier property to provide fine detail of the primitive type.
Number
Represents a numeric value in OpenAPI schema validation fields.
Schema
Is super type for OpenAPI Schema Object. Schema is reusable resource what can be referenced from path operations and other components using Ref.
SchemaFormat
Additional format for SchemaType to fine tune the data type used.
SchemaType
Represents type of Schema.

Functions

empty
Create an empty Schema that serializes to null.