#[non_exhaustive]pub struct Discriminator {
pub property_name: String,
pub mapping: PropMap<String, String>,
pub default_mapping: Option<String>,
pub extensions: PropMap<String, Value>,
}Expand description
OpenAPI Discriminator object which can be optionally used together with
OneOf composite object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.property_name: StringDefines a discriminator property name which must be found within all composite objects.
mapping: PropMap<String, String>An object to hold mappings between payload values and schema names or references. This field can only be populated manually. There is no macro support and no validation.
default_mapping: Option<String>The schema name or URI reference to the schema that validates the payload when the discriminating property is absent, or holds a value with no explicit or implicit mapping. Added in OpenAPI 3.2.
Required by the spec when the discriminating property is optional.
See https://spec.openapis.org/oas/v3.2.0.html#discriminator-object.
extensions: PropMap<String, Value>Optional extensions “x-something”
Implementations
Sourceimpl Discriminator
impl Discriminator
Sourcepub fn new<I: Into<String>>(property_name: I) -> Self
pub fn new<I: Into<String>>(property_name: I) -> Self
Construct a new Discriminator object with property name.
Examples
Create a new Discriminator object for pet_type property.
let discriminator = Discriminator::new("pet_type");Sourcepub fn add_mapping<K: Into<String>, V: Into<String>>(
self,
value: K,
schema: V,
) -> Self
pub fn add_mapping<K: Into<String>, V: Into<String>>( self, value: K, schema: V, ) -> Self
Add a mapping between a payload value and a schema name or URI reference.
Sourcepub fn default_mapping<I: Into<String>>(self, default_mapping: I) -> Self
pub fn default_mapping<I: Into<String>>(self, default_mapping: I) -> Self
Set the fallback schema used when the discriminating property is missing or unmapped. Requires OpenAPI 3.2.
Sourcepub fn extensions(self, extensions: PropMap<String, Value>) -> Self
pub fn extensions(self, extensions: PropMap<String, Value>) -> Self
Add openapi extensions (x-something) for Discriminator.