#[non_exhaustive]pub struct License {
pub name: String,
pub url: Option<String>,
pub identifier: Option<String>,
pub extensions: PropMap<String, Value>,
}Expand description
OpenAPI License information of the API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of the license used e.g MIT or Apache-2.0
url: Option<String>Optional url pointing to the license.
identifier: Option<String>An SPDX-Licenses expression for the API. The identifier field
is mutually exclusive of the url field. E.g. Apache-2.0
extensions: PropMap<String, Value>Optional extensions “x-something”
Implementations
Sourceimpl License
impl License
Sourcepub fn new<S: Into<String>>(name: S) -> Self
pub fn new<S: Into<String>>(name: S) -> Self
Construct a new License object.
Function takes name of the license as an argument e.g MIT.
Sourcepub fn identifier<S: Into<String>>(self, identifier: S) -> Self
pub fn identifier<S: Into<String>>(self, identifier: S) -> Self
Set identifier of the licence as SPDX-Licenses expression for the API.
The identifier field is mutually exclusive of the url field. E.g. Apache-2.0