#[non_exhaustive]pub struct Link {
pub operation_ref: String,
pub operation_id: String,
pub parameters: PropMap<String, Value>,
pub request_body: Option<Value>,
pub description: String,
pub server: Option<Server>,
}Expand description
Implements Open API Link Object for responses.
The Link represents possible design time link for a response. It does not guarantee
callers ability to invoke it but rather provides known relationship between responses and
other operations.
For computing links, and providing instructions to execute them, a runtime expression is used for accessing values in an operation and using them as parameters while invoking the linked operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.operation_ref: StringA relative or absolute URI reference to an OAS operation. This field is
mutually exclusive of the operation_id field, and must point to an Operation
Object.
Relative operation_ref values may be used to locate an existing Operation
Object in the OpenAPI definition. See the rules for resolving Relative
References.
operation_id: StringThe name of an existing, resolvable OAS operation, as defined with a unique
operation_id.
This field is mutually exclusive of the operation_ref field.
parameters: PropMap<String, Value>A map representing parameters to pass to an operation as specified with operation_id
or identified by operation_ref. The key is parameter name to be used and value can
be any value supported by JSON or an expression e.g. $path.id
request_body: Option<Value>A literal value or an expression to be used as request body when operation is called.
description: StringDescription of the link. Value supports Markdown syntax.
server: Option<Server>A Server object to be used by the target operation.
Implementations
Sourceimpl Link
impl Link
Sourcepub fn operation_ref<S: Into<String>>(self, operation_ref: S) -> Self
pub fn operation_ref<S: Into<String>>(self, operation_ref: S) -> Self
Set a relative or absolute URI reference to an OAS operation. This field is
mutually exclusive of the operation_id field, and must point to an Operation
Object.
Sourcepub fn operation_id<S: Into<String>>(self, operation_id: S) -> Self
pub fn operation_id<S: Into<String>>(self, operation_id: S) -> Self
Set the name of an existing, resolvable OAS operation, as defined with a unique
operation_id.
This field is mutually exclusive of the operation_ref field.
Sourcepub fn parameter<N: Into<String>, V: Into<Value>>(
self,
name: N,
value: V,
) -> Self
pub fn parameter<N: Into<String>, V: Into<Value>>( self, name: N, value: V, ) -> Self
Add parameter to be passed to Operation upon execution.
Sourcepub fn request_body<B: Into<Value>>(self, request_body: Option<B>) -> Self
pub fn request_body<B: Into<Value>>(self, request_body: Option<B>) -> Self
Set a literal value or an expression to be used as request body when operation is called.
Sourcepub fn description<S: Into<String>>(self, description: S) -> Self
pub fn description<S: Into<String>>(self, description: S) -> Self
Set description of the link. Value supports Markdown syntax.