Implements OpenAPI Schema Object types which can be used to define field properties, enum values, array or object types.
Structs
- AllOf
- AllOf Composite Object component holds multiple components together where API endpoint will return a combination of all of them.
- AnyOf
- AnyOf Composite Object component holds multiple components together where API endpoint will return a combination of all of them.
- Array
- Array represents
Vecorslicetype of items. - Discriminator
- OpenAPI Discriminator object which can be optionally used together with
OneOfcomposite object. - Object
- Implements subset of OpenAPI Schema Object which allows
adding other
Schemas as properties to thisSchema. - OneOf
- OneOf Composite Object component holds multiple components together where API endpoint could return any of them.
- Ref
- Implements OpenAPI Reference Object that can be used to reference
reusable components such as
Schemas orResponses. - Schemas
- Schemas collection for OpenApi.
Enums
- Additional
Properties - AdditionalProperties is used to define values of map fields of the
Schema. - Array
Items - Represents
Arrayitems in JSON Schema Array. - Basic
Type - Represents data type fragment of
Schema. - Known
Format - Known schema format modifier property to provide fine detail of the primitive type.
- Number
- Represents a numeric value in OpenAPI schema validation fields.
- Schema
- Is super type for OpenAPI Schema Object. Schema is reusable resource what can be
referenced from path operations and other components using
Ref. - Schema
Format - Additional format for
SchemaTypeto fine tune the data type used. - Schema
Type - Represents type of
Schema.